@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
 """
 Main interface for machinelearning service client paginators.
 
@@ -7,7 +8,7 @@ Usage::
     import boto3
 
     from mypy_boto3_machinelearning import MachineLearningClient
-    from mypy_boto3_machinelearning import (
+    from mypy_boto3_machinelearning.paginator import (
         DescribeBatchPredictionsPaginator,
         DescribeDataSourcesPaginator,
         DescribeEvaluationsPaginator,
@@ -22,10 +23,11 @@ Usage::
     describe_ml_models_paginator: DescribeMLModelsPaginator = client.get_paginator("describe_ml_models")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import Iterator, TYPE_CHECKING
+from typing import Iterator
+
 from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_machinelearning.type_defs import (
     DescribeBatchPredictionsOutputTypeDef,
     DescribeDataSourcesOutputTypeDef,
@@ -50,7 +52,7 @@ __all__ = (
 
 class DescribeBatchPredictionsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeBatchPredictions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeBatchPredictions)
+    [Paginator.DescribeBatchPredictions documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeBatchPredictions)
     """
 
     def paginate(
@@ -76,13 +78,13 @@ class DescribeBatchPredictionsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeBatchPredictionsOutputTypeDef]:
         """
-        [DescribeBatchPredictions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeBatchPredictions.paginate)
+        [DescribeBatchPredictions.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeBatchPredictions.paginate)
         """
 
 
 class DescribeDataSourcesPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeDataSources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeDataSources)
+    [Paginator.DescribeDataSources documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeDataSources)
     """
 
     def paginate(
@@ -101,13 +103,13 @@ class DescribeDataSourcesPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeDataSourcesOutputTypeDef]:
         """
-        [DescribeDataSources.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeDataSources.paginate)
+        [DescribeDataSources.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeDataSources.paginate)
         """
 
 
 class DescribeEvaluationsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeEvaluations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeEvaluations)
+    [Paginator.DescribeEvaluations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeEvaluations)
     """
 
     def paginate(
@@ -133,13 +135,13 @@ class DescribeEvaluationsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeEvaluationsOutputTypeDef]:
         """
-        [DescribeEvaluations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeEvaluations.paginate)
+        [DescribeEvaluations.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeEvaluations.paginate)
         """
 
 
 class DescribeMLModelsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeMLModels documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeMLModels)
+    [Paginator.DescribeMLModels documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeMLModels)
     """
 
     def paginate(
@@ -167,5 +169,5 @@ class DescribeMLModelsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeMLModelsOutputTypeDef]:
         """
-        [DescribeMLModels.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeMLModels.paginate)
+        [DescribeMLModels.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/machinelearning.html#MachineLearning.Paginator.DescribeMLModels.paginate)
         """
