@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 """
 Main interface for machinelearning service client waiters.
 
@@ -7,7 +8,7 @@ Usage::
     import boto3
 
     from mypy_boto3_machinelearning import MachineLearningClient
-    from mypy_boto3_machinelearning import (
+    from mypy_boto3_machinelearning.waiter import (
         BatchPredictionAvailableWaiter,
         DataSourceAvailableWaiter,
         EvaluationAvailableWaiter,
@@ -22,10 +23,10 @@ Usage::
     ml_model_available_waiter: MLModelAvailableWaiter = client.get_waiter("ml_model_available")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
-from typing import TYPE_CHECKING
+
 from botocore.waiter import Waiter as Boto3Waiter
+
 from mypy_boto3_machinelearning.type_defs import WaiterConfigTypeDef
 
 if sys.version_info >= (3, 8):
@@ -44,7 +45,7 @@ __all__ = (
 
 class BatchPredictionAvailableWaiter(Boto3Waiter):
     """
-    [Waiter.BatchPredictionAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/machinelearning.html#MachineLearning.Waiter.BatchPredictionAvailable)
+    [Waiter.BatchPredictionAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/machinelearning.html#MachineLearning.Waiter.BatchPredictionAvailable)
     """
 
     def wait(
@@ -72,13 +73,13 @@ class BatchPredictionAvailableWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [BatchPredictionAvailable.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/machinelearning.html#MachineLearning.Waiter.BatchPredictionAvailable.wait)
+        [BatchPredictionAvailable.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/machinelearning.html#MachineLearning.Waiter.BatchPredictionAvailable.wait)
         """
 
 
 class DataSourceAvailableWaiter(Boto3Waiter):
     """
-    [Waiter.DataSourceAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/machinelearning.html#MachineLearning.Waiter.DataSourceAvailable)
+    [Waiter.DataSourceAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/machinelearning.html#MachineLearning.Waiter.DataSourceAvailable)
     """
 
     def wait(
@@ -99,13 +100,13 @@ class DataSourceAvailableWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [DataSourceAvailable.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/machinelearning.html#MachineLearning.Waiter.DataSourceAvailable.wait)
+        [DataSourceAvailable.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/machinelearning.html#MachineLearning.Waiter.DataSourceAvailable.wait)
         """
 
 
 class EvaluationAvailableWaiter(Boto3Waiter):
     """
-    [Waiter.EvaluationAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/machinelearning.html#MachineLearning.Waiter.EvaluationAvailable)
+    [Waiter.EvaluationAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/machinelearning.html#MachineLearning.Waiter.EvaluationAvailable)
     """
 
     def wait(
@@ -133,13 +134,13 @@ class EvaluationAvailableWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [EvaluationAvailable.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/machinelearning.html#MachineLearning.Waiter.EvaluationAvailable.wait)
+        [EvaluationAvailable.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/machinelearning.html#MachineLearning.Waiter.EvaluationAvailable.wait)
         """
 
 
 class MLModelAvailableWaiter(Boto3Waiter):
     """
-    [Waiter.MLModelAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/machinelearning.html#MachineLearning.Waiter.MLModelAvailable)
+    [Waiter.MLModelAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/machinelearning.html#MachineLearning.Waiter.MLModelAvailable)
     """
 
     def wait(
@@ -169,5 +170,5 @@ class MLModelAvailableWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [MLModelAvailable.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.26/reference/services/machinelearning.html#MachineLearning.Waiter.MLModelAvailable.wait)
+        [MLModelAvailable.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.3/reference/services/machinelearning.html#MachineLearning.Waiter.MLModelAvailable.wait)
         """
